From fd5d099065a748cac49e20a13481f85666c53c71 Mon Sep 17 00:00:00 2001
From: Timothy Pearson <kb9vqf@pearsoncomputing.net>
Date: Fri, 1 Feb 2013 15:14:12 -0600
Subject: Rename a number of classes to enhance compatibility with KDE4

---
 libtdepim/kpixmapregionselectorwidget.h | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

(limited to 'libtdepim/kpixmapregionselectorwidget.h')

diff --git a/libtdepim/kpixmapregionselectorwidget.h b/libtdepim/kpixmapregionselectorwidget.h
index caad8fc3f..9af02c2ce 100644
--- a/libtdepim/kpixmapregionselectorwidget.h
+++ b/libtdepim/kpixmapregionselectorwidget.h
@@ -28,7 +28,7 @@
 #include <tqlabel.h>
 #include <kimageeffect.h>
 
-class KPopupMenu;
+class TDEPopupMenu;
 
 namespace KPIM {
 
@@ -139,9 +139,9 @@ public slots:
 
 protected:
    /**
     * Creates a KPopupMenu with the menu that appears when clicking with the right button on the label
     */
-   virtual KPopupMenu *createPopupMenu();
+   virtual TDEPopupMenu *createPopupMenu();
 
 
 private:
@@ -139,9 +139,9 @@ public slots:
 protected:
    /**
-    * Creates a KPopupMenu with the menu that appears when clicking with the right button on the label
+    * Creates a TDEPopupMenu with the menu that appears when clicking with the right button on the label
     */
-- 
cgit v1.2.1